# coding: utf-8

class ClaimResponse(object):

    """
    Attributes:
      openapi_spec_types (dict): The key is attribute name and the value is attribute type.
      attribute_serialization_map (dict): The key is attribute name and the value is json key in definition.
    """
    openapi_spec_types = {
    }

    attribute_serialization_map = {
    }

    def __init__(self):
        """ClaimResponse"""
